"use strict";(self.webpackChunknbvv=self.webpackChunknbvv||[]).push([[174],{51568:function(e,n,t){var a=this&&this.__createBinding||(Object.create?function(e,n,t,a){void 0===a&&(a=t),Object.defineProperty(e,a,{enumerable:!0,get:function(){return n[t]}})}:function(e,n,t,a){void 0===a&&(a=t),e[a]=n[t]}),r=this&&this.__setModuleDefault||(Object.create?function(e,n){Object.defineProperty(e,"default",{enumerable:!0,value:n})}:function(e,n){e.default=n}),l=this&&this.__importStar||function(e){if(e&&e.__esModule)return e;var n={};if(null!=e)for(var t in e)"default"!==t&&Object.prototype.hasOwnProperty.call(e,t)&&a(n,e,t);return r(n,e),n},i=this&&this.__importDefault||function(e){return e&&e.__esModule?e:{default:e}};Object.defineProperty(n,"__esModule",{value:!0}),n.VolumeWidgetView=void 0;const o=l(t(22187)),d=t(98803),s=i(t(56271)),c=i(t(14456));t(26946),t(54840);var u=o.DOMWidgetView.extend({initialize:function(){this.model.get("metadata");const e=this.model.get("image"),n=(this.model.get("size"),this.model.get("density"),this.model.get("brightness"),this.model.get("dimensions"));e.shape[1],e.shape[2],e.shape[3],e.shape[0],e.shape[1];const t=s.default.createElement("div",{className:"cell-viewer"},s.default.createElement(d.ImageViewerApp,{rawData:e,rawDims:n,appHeight:"400px",renderConfig:{alphaMask:!0,autoRotateButton:!0,axisClipSliders:!0,brightnessSlider:!0,colorPicker:!0,colorPresetsDropdown:!0,densitySlider:!0,fovCellSwitchControls:!1,levelsSliders:!0,saveSurfaceButtons:!0,viewModeRadioButtons:!0},viewerChannelSettings:{groups:[{name:"Channels",channels:n.channel_names.map(((e,n)=>({match:e,enabled:n<3})))}]}},null)),a=document.createElement("div");c.default.render(t,a),this.el.append(a),setTimeout((()=>{window.dispatchEvent(new Event("resize"))}),200)}});n.VolumeWidgetView=u},12338:(e,n,t)=>{t.d(n,{Z:()=>o});var a=t(8081),r=t.n(a),l=t(23645),i=t.n(l)()(r());i.push([e.id,"/* stylelint-disable at-rule-empty-line-before,at-rule-name-space-after,at-rule-no-unknown */\n/* stylelint-disable no-duplicate-selectors */\n/* stylelint-disable */\n/* stylelint-disable declaration-bang-space-before,no-duplicate-selectors,string-no-newline */\n:root {\n  --background-dark-gray: #131313;\n  --background-black-purple: #222222;\n  --background-dim-gray: #383838;\n  --purple: #8950d9;\n  --dimgray: #6e6e6e;\n  --highlight-green: #b2d030;\n  --bright-blue: #00a0ff;\n  --text-gray: #a0a0a0;\n  --header-gray: #4b4b4b;\n  --panel-body-background-gray: #313131;\n  --light-gray: #aeacae;\n  --off-white: #f8f8f8;\n  --border-gray: var(--dimgray);\n  --dark-theme-text-color: var(--off-white);\n  --bottom-panel: var(--background-black-purple);\n  --bottom-panel-trigger: var(--header-gray);\n  --bottom-panel-trigger-label: var(--light-gray);\n  --megacard-background: var(--background-dim-gray);\n  --link-text: var(--bright-blue);\n}\n.cell-viewer {\n  display: flex;\n  flex: 1;\n  width: 100%;\n  background: #ff0000;\n}\n.cell-viewer .ant-layout-sider {\n  background: #ffffff;\n}\n.cell-viewer .ant-drawer-wrapper-body {\n  opacity: 65%;\n}\n.cell-viewer :global(.ant-drawer-title .ant-btn) {\n  background-color: var(--bottom-panel-trigger);\n  color: var(--bottom-panel-trigger-label);\n}\n.cell-viewer :global(.ant-drawer-title .ant-btn:focus) {\n  color: var(--bottom-panel-trigger-label);\n}\n.cell-viewer :global(.drawer.ant-drawer-open .ant-drawer-body) {\n  background-color: var(--bottom-panel);\n}\n.cell-viewer :global(.drawer.ant-drawer-open .ant-drawer-title .ant-btn) {\n  background-color: var(--bottom-panel);\n}\n",""]);const o=i},54840:(e,n,t)=>{t.r(n),t.d(n,{default:()=>m});var a=t(93379),r=t.n(a),l=t(7795),i=t.n(l),o=t(90569),d=t.n(o),s=t(3565),c=t.n(s),u=t(19216),g=t.n(u),b=t(44589),p=t.n(b),h=t(12338),f={};f.styleTagTransform=p(),f.setAttributes=c(),f.insert=d().bind(null,"head"),f.domAPI=i(),f.insertStyleElement=g(),r()(h.Z,f);const m=h.Z&&h.Z.locals?h.Z.locals:void 0},25145:e=>{e.exports="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAoCAYAAACWwljjAAAABGdBTUEAALGPC/xhBQAAAbtJREFUWAntmMtKw0AUhhMvS5cuxILgQlRUpIggIoKIIoigG1eC+AA+jo+i6FIXBfeuXIgoeKVeitVWJX5HWhhDksnUpp3FDPyZk3Nm5nycmZKkXhAEOXSA3lG7muTeRzmfy6HneUvIhnYkQK+Q9NhAA0Opg0vBEhjBKHiyb8iGMyQMOYuK41BcBSypAL+MYXSKjtFAW7EAGEO3qN4uMQbbAkXiSfRQJ1H6a+yhlkKRcAoVFYiweYNjtCVQJJpBz2GCiPt7fBOZQpFgDpUikse5HgnkM4Fi4QX0Fpc5wf9EbLqpUCy4jMoJSXWhFwbMNgWKhVbRhy5jirhs9fy/oFhgHVVTJEs7RLZ8sSEoJm6iz7SZDMbJ+/OKERQTttCXQRLToRUmrKWCYuA2+jbN0MB4OQobYShfdTCgn/sL1K36M7TLrN3n+758aPy2rrpR6+/od5E8tf/A1uLS9aId5T7J3CNYihkQ4D9PiMdMC7mp4rjB9kjFjZp8BlnVHJBuO1yFXIV0FdDF3RlyFdJVQBdv5AxVdIsq8apiZ2PyYO1EVykesGfZEESsCkweyR8MUW+V8uJ1gkYipmpdP1pm2aJVPEGzAAAAAElFTkSuQmCC"}}]);