"use strict";(self.webpackChunknbvv=self.webpackChunknbvv||[]).push([[522],{5522:(e,r,n)=>{n.r(r),n.d(r,{default:()=>a});var s=n(7885),u=n(7737);class a extends u.Z{decodeBlock(e){return(0,s.rr)(new Uint8Array(e)).buffer}}}}]);
//# sourceMappingURL=522.index.js.map