(()=>{var e,r,t={72672:(e,r,t)=>{"use strict";var a=t(92137),n=t(87757),o=t.n(n),c=t(38324);self.onmessage=function(){var e=(0,a.Z)(o().mark((function e(r){var t,a,n,s,i,f,d,l,u,b,p,v,h,g,y,m,w,x,S,O,E,T,P,j;return o().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return t=r.data.channel,a=r.data.tilesizex,n=r.data.tilesizey,s=r.data.sizez,i=r.data.sizec,f=r.data.dimensionOrder,d=r.data.bytesPerSample,e.next=9,(0,c.W0)(r.data.url);case 9:l=e.sent,u=new Uint16Array(a*n*s),b=new Uint8Array(a*n*s),p=0,v=1,"XYZCT"===f?(p=s*t,v=1):"XYCZT"===f&&(p=t,v=i),h=p,g=0;case 16:if(!(g<s)){e.next=29;break}return e.next=19,l.getImage(h);case 19:return y=e.sent,e.next=22,y.readRasters({width:a,height:n});case 22:m=e.sent,w=Array.isArray(m)?m[0]:m,x=g*a*n,2===w.BYTES_PER_ELEMENT?u.set(w,x):1===w.BYTES_PER_ELEMENT?b.set(w,x):console.log("byte size not supported yet");case 26:h+=v,++g,e.next=16;break;case 29:if(2===d){for(S=65535,O=0,E=0;E<u.length;++E)(T=u[E])<S&&(S=T),T>O&&(O=T);for(P=0;P<u.length;++P)b[P]=(u[P]-S)/(O-S)*255}else 1===d||console.log("byte size not supported yet");j={data:b,channel:t},postMessage(j,[j.data.buffer]);case 32:case"end":return e.stop()}}),e)})));return function(r){return e.apply(this,arguments)}}()},73752:()=>{},13640:()=>{},82630:()=>{}},a={};function n(e){var r=a[e];if(void 0!==r)return r.exports;var o=a[e]={exports:{}};return t[e](o,o.exports,n),o.exports}n.m=t,n.c=a,n.x=()=>{var e=n.O(void 0,[368],(()=>n(72672)));return n.O(e)},e=[],n.O=(r,t,a,o)=>{if(!t){var c=1/0;for(d=0;d<e.length;d++){for(var[t,a,o]=e[d],s=!0,i=0;i<t.length;i++)(!1&o||c>=o)&&Object.keys(n.O).every((e=>n.O[e](t[i])))?t.splice(i--,1):(s=!1,o<c&&(c=o));if(s){e.splice(d--,1);var f=a();void 0!==f&&(r=f)}}return r}o=o||0;for(var d=e.length;d>0&&e[d-1][2]>o;d--)e[d]=e[d-1];e[d]=[t,a,o]},n.n=e=>{var r=e&&e.__esModule?()=>e.default:()=>e;return n.d(r,{a:r}),r},n.d=(e,r)=>{for(var t in r)n.o(r,t)&&!n.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:r[t]})},n.f={},n.e=e=>Promise.all(Object.keys(n.f).reduce(((r,t)=>(n.f[t](e,r),r)),[])),n.u=e=>e+"."+{81:"3ddc237a322e7e357127",193:"f50e4726b46e72dcaf3d",260:"f94c61c9f5187b0449dc",368:"4374d496274cb817a2dc",539:"e0f1a07c5a4fd5880b99",562:"5145c6feda7565fc789f",838:"15168037eca4c554e9da",867:"0f08adbd268a7afcc980",958:"61fa82eea1ddd90c9b68"}[e]+".js?v="+{81:"3ddc237a322e7e357127",193:"f50e4726b46e72dcaf3d",260:"f94c61c9f5187b0449dc",368:"4374d496274cb817a2dc",539:"e0f1a07c5a4fd5880b99",562:"5145c6feda7565fc789f",838:"15168037eca4c554e9da",867:"0f08adbd268a7afcc980",958:"61fa82eea1ddd90c9b68"}[e],n.g=function(){if("object"==typeof globalThis)return globalThis;try{return this||new Function("return this")()}catch(e){if("object"==typeof window)return window}}(),n.o=(e,r)=>Object.prototype.hasOwnProperty.call(e,r),n.r=e=>{"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},(()=>{n.S={};var e={},r={};n.I=(t,a)=>{a||(a=[]);var o=r[t];if(o||(o=r[t]={}),!(a.indexOf(o)>=0)){if(a.push(o),e[t])return e[t];n.o(n.S,t)||(n.S[t]={}),n.S[t];var c=[];return e[t]=c.length?Promise.all(c).then((()=>e[t]=1)):1}}})(),(()=>{var e;n.g.importScripts&&(e=n.g.location+"");var r=n.g.document;if(!e&&r&&(r.currentScript&&(e=r.currentScript.src),!e)){var t=r.getElementsByTagName("script");t.length&&(e=t[t.length-1].src)}if(!e)throw new Error("Automatic publicPath is not supported in this browser");e=e.replace(/#.*$/,"").replace(/\?.*$/,"").replace(/\/[^\/]+$/,"/"),n.p=e})(),(()=>{var e={930:1,733:1};n.f.i=(r,t)=>{e[r]||importScripts(n.p+n.u(r))};var r=self.webpackChunknbvv=self.webpackChunknbvv||[],t=r.push.bind(r);r.push=r=>{var[a,o,c]=r;for(var s in o)n.o(o,s)&&(n.m[s]=o[s]);for(c&&c(n);a.length;)e[a.pop()]=1;t(r)}})(),r=n.x,n.x=()=>n.e(368).then(r),n.x()})();